<template>
  <el-dialog
    top="5vh"
    :title="!dataForm.id ? '新增' : '修改'"
    :close-on-click-modal="false"
    :visible.sync="visible"
  >
    <el-tabs type="border-card" ref="tabs">
      <el-tab-pane label="主要">
        <el-form
          :model="dataForm"
          :rules="dataRule"
          ref="dataForm"
          label-width="80px"
          class="l-mes"
          :disabled="!editable"
        >
          <el-row :gutter="10">
            <el-col :span="12">
              <el-form-item label="送货单号" prop="receiveNo">
                <el-input
                  v-model="dataForm.receiveNo"
                  placeholder=""
                ></el-input>
              </el-form-item>
            </el-col>
            <el-col :span="12">
              <el-form-item label="采购单号" prop="purchaseNo">
                <el-input
                  v-model="dataForm.purchaseNo"
                  placeholder=""
                ></el-input>
              </el-form-item>
            </el-col>
          </el-row>
          <el-row :gutter="10">
            <el-col :span="12">
              <el-form-item label="行号" prop="lineNo">
                <el-input v-model="dataForm.lineNo" placeholder=""></el-input>
              </el-form-item>
            </el-col>
            <el-col :span="12">
              <el-form-item label="下达号" prop="releaseNo">
                <el-input
                  v-model="dataForm.releaseNo"
                  placeholder=""
                ></el-input>
              </el-form-item>
            </el-col>
          </el-row>
          <el-row :gutter="10">
            <el-col :span="12">
              <el-form-item label="供应商" prop="supplierNo">
                <el-input
                  v-model="dataForm.supplierNo"
                  placeholder=""
                ></el-input>
              </el-form-item>
            </el-col>
            <el-col :span="12">
              <el-form-item label="工厂" prop="factoryId">
                <el-select
                  v-model="dataForm.factoryId"
                  filterable
                  placeholder=""
                  style="width:100%"
                >
                  <el-option
                    v-for="item in factoryOptions"
                    :key="item.id"
                    :label="item.factoryName"
                    :value="item.id"
                  >
                  </el-option>
                </el-select>
              </el-form-item>
            </el-col>
          </el-row>
          <el-row :gutter="10">
            <el-col :span="12">
              <el-form-item label="入库类型" prop="receiveType">
                <el-select
                  v-model="dataForm.receiveType"
                  filterable
                  placeholder=""
                  style="width:100%"
                >
                  <el-option
                    v-for="item in receiveTypes"
                    :key="item.id"
                    :label="item.stockCodeName"
                    :value="item.id"
                  >
                  </el-option>
                </el-select>
              </el-form-item>
            </el-col>
            <el-col :span="12">
              <el-form-item label="收货时间" prop="receiveTime">
                <el-date-picker
                  v-model="dataForm.receiveTime"
                  style="width: 100%"
                  type="datetime"
                  value-format="yyyy-MM-dd HH:mm:ss"
                >
                </el-date-picker>
              </el-form-item>
            </el-col>
          </el-row>
          <el-row :gutter="10">
            <el-col :span="12">
              <el-form-item label="送货人" prop="deliverymanName">
                <el-input
                  v-model="dataForm.deliverymanName"
                  placeholder=""
                ></el-input>
              </el-form-item>
            </el-col>
            <el-col :span="12">
              <el-form-item label="送货人电话" prop="deliverymanPhone">
                <el-input
                  v-model="dataForm.deliverymanPhone"
                  placeholder=""
                ></el-input>
              </el-form-item>
            </el-col>
          </el-row>
          <el-row :gutter="10">
            <el-col :span="12">
              <el-form-item label="审核状态" prop="receiveStatus">
                <el-switch disabled v-model="dataForm.receiveStatus" />
              </el-form-item>
            </el-col>
          </el-row>
        </el-form>
      </el-tab-pane>

      <el-tab-pane label="PDA收料明细">
        <receiving-detail
          :visible="visible"
          :paramObj="paramObj"
          :disabled="dataForm.receiveStatus"
          ref="receivingDetail"
          @refreshDataList="refreshDeliveryDataList"
        ></receiving-detail>
      </el-tab-pane>

      <el-tab-pane label="送货清单">
        <delivery-detail
          :visible="visible"
          :paramObj="paramObj"
          :disabled="dataForm.receiveStatus"
          ref="deliveryDetail"
          @refreshDataList="refreshDataList"
        ></delivery-detail>
      </el-tab-pane>
    </el-tabs>

    <span slot="footer" class="dialog-footer">
      <el-button
        type="primary"
        :loading="saveLoading"
        @click="dataFormSubmit(false)"
        >保存</el-button
      >
      <el-button
        type="primary"
        :loading="saveAndReturnLoading"
        @click="dataFormSubmit(true)"
        >保存并返回</el-button
      >
    </span>
  </el-dialog>
</template>

<script>
import {
  getReceiving,
  addReceiving,
  putReceiving
} from '@/api/warehouse/receiving'
import { loadStockInCode } from '@/api/warehouse/stockincode'
import { loadFactoryList } from '@/api/basic/factory'
import ReceivingDetail from './receiving-detail-index'
import DeliveryDetail from './delivery-detail-index'

export default {
  data() {
    return {
      paramObj: {},
      visible: false,
      dataForm: {
        id: 0,
        receiveNo: '',
        purchaseNo: '',
        supplierNo: '',
        lineNo: '',
        releaseNo: '',
        factoryId: '',
        receiveType: '',
        receiveTime: '',
        deliverymanName: '',
        deliverymanPhone: '',
        receiveStatus: false,
        receivingDetails: []
      },
      dataRule: {
        receiveNo: [
          { required: true, message: '送货单号不能为空', trigger: 'blur' }
        ],
        purchaseNo: [
          { required: true, message: '采购单号不能为空', trigger: 'blur' }
        ],
        receiveType: [
          { required: true, message: '入库类型不能为空', trigger: 'blur' }
        ],
        receiveTime: [
          { required: true, message: '收货时间不能为空', trigger: 'blur' }
        ]
      },
      factoryOptions: [],
      receiveTypes: [],
      saveLoading: false,
      saveAndReturnLoading: false
    }
  },
  computed: {
    editable: function() {
      if (!this.dataForm.id) {
        return true
      }
      if (this.dataForm.id && this.dataForm.receiveStatus == false) {
        return true
      }
      return false
    }
  },
  created() {
    this.initFactorySelect()
    this.initReceiveTypeSelect()
  },
  components: {
    ReceivingDetail,
    DeliveryDetail
  },
  methods: {
    init(id) {
      this.dataForm.id = id || 0
      this.visible = true
      this.paramObj.receivingMainId = this.dataForm.id
      this.$nextTick(() => {
        this.$refs.dataForm.resetFields()
        if (this.dataForm.id) {
          getReceiving(this.dataForm.id).then((response) => {
            this.dataForm = response.data.data
            this.paramObj.factoryId = this.dataForm.factoryId
          })
        } else {
          this.$refs.tabs.currentName = '0'
        }
      })
    },
    // 表单提交
    dataFormSubmit(flag) {
      if (flag) {
        this.saveAndReturnLoading = true
      } else {
        this.saveLoading = true
      }
      this.$refs.dataForm.validate((valid) => {
        if (valid) {
          if (this.dataForm.id) {
            putReceiving(this.dataForm).then((response) => {
              this.dataForm.id = response.data.data
              this.$message.success('修改成功')
              this.init(this.dataForm.id)
              this.$emit('refreshDataList')
              if (flag) {
                this.visible = false
                this.saveAndReturnLoading = false
              } else {
                this.saveLoading = false
              }
            })
          } else {
            addReceiving(this.dataForm).then((response) => {
              this.dataForm.id = response.data.data
              this.$message.success('添加成功')
              this.$emit('refreshDataList')
              this.init(this.dataForm.id)
              if (flag) {
                this.visible = false
                this.saveAndReturnLoading = false
              } else {
                this.saveLoading = false
              }
            })
          }
        } else {
          this.saveAndReturnLoading = false
          this.saveLoading = false
        }
      })
    },
    // 1.主要
    // 获取工厂的数据
    initFactorySelect() {
      loadFactoryList().then((res) => {
        this.factoryOptions = res.data
      })
    },
    // 获取入库类型
    initReceiveTypeSelect() {
      loadStockInCode(
        Object.assign({
          stockCodeType: 0,
          stockCodeStatus: 1
        })
      ).then((res) => {
        this.receiveTypes = res.data.data
      })
    },
    // 2.收料明细
    refreshDeliveryDataList() {
      this.$refs.deliveryDetail.getData()
    },
    // 3.送货清单
    refreshDataList() {
      this.init(this.dataForm.id)
      this.$emit('refreshDataList')
    }
  }
}
</script>
